@@ -3,7 +3,7 @@ import hashlib
 import random
 import secrets
 import smtplib
-import pywebpush
+from pywebpush import webpush
 
 import bcrypt
 import jwt
@@ -582,6 +582,7 @@ class Node(db.Model):
 
 class PushSubscription(db.Model):
     __tablename__ = "mitama_push_subscription"
+    _project = None
     user_id = Column(String(64), ForeignKey("mitama_user._id", ondelete="CASCADE"))
     user = relationship("User", backref="subscriptions")
     subscription = Column(String(1024))
@@ -590,10 +591,10 @@ class PushSubscription(db.Model):
         try:
             webpush(
                 subscription_info=json.loads(self.subscription),
-                data=data,
-                vapid_private_key=self.project.vapid.private_key,
+                data=json.dumps(data),
+                vapid_private_key=self._project.vapid['private_key'],
                 vapid_claims={
-                    "sub": "mailto:{}".format(self.project.vapid.mailto)
+                    "sub": "mailto:{}".format(self._project.vapid['mailto'])
                 }
             )
         except Exception as err:
